AbrevvaCryptoError enum
Values
- encryptCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('EncryptCryptoError') - encryptEmptyResultError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('EncryptEmptyResultError') - encryptInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('EncryptInvalidArgumentError') - encryptFileCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('EncryptFileCryptoError') - encryptFileInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('EncryptFileInvalidArgumentError') - decryptInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptInvalidArgumentError') - decryptEmptyResultError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptEmptyResultError') - decryptCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptCryptoError') - decryptFileCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileCryptoError') - decryptFileInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileInvalidArgumentError') - decryptFileFromURLNetworkError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLNetworkError') - decryptFileFromURLNotFoundError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLNotFoundError') - decryptFileFromURLInaccessibleError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLInaccessibleError') - decryptFileFromURLNoResponseDataError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLNoResponseDataError') - decryptFileFromURLInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLInvalidArgumentError') - decryptFileFromURLCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DecryptFileFromURLCryptoError') - generateKeypairError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('GenerateKeypairError') -
const AbrevvaCryptoError('ComputeSharedSecretError') -
const AbrevvaCryptoError('ComputeSharedSecretInvalidArgumentError') - computeED25519PublicKeyError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('ComputeED25519PublicKeyError') - computeED25519PublicKeyInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('ComputeED25519PublicKeyInvalidArgumentError') - signCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('SignCryptoError') - signInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('SignInvalidArgumentError') - verifyCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('VerifyCryptoError') - verifyFailedError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('VerifyFailedError') - verifyInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('VerifyInvalidArgumentError') - randomError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('RandomError') - deriveInvalidArgumentError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DeriveInvalidArgumentError') - deriveEmptyResultError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DeriveEmptyResultError') - deriveCryptoError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('DeriveCryptoError') - unkownError → const AbrevvaCryptoError
-
const AbrevvaCryptoError('UnkownError')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String code) → AbrevvaCryptoError?
Constants
-
values
→ const List<
AbrevvaCryptoError> - A constant List of the values in this enum, in order of their declaration.